Enum sc_service::config::BasePath [−][src]
The base path that is used for everything that needs to be write on disk to run a node.
Variants
Temporary(TempDir)A temporary directory is used as base path and will be deleted when dropped.
Tuple Fields of Temporary
0: TempDirPermanenent(PathBuf)A path on the disk.
Tuple Fields of Permanenent
0: PathBufImplementations
Create a BasePath instance using a temporary directory prefixed with “substrate” and use
it as base path.
Note: the temporary directory will be created automatically and deleted when the BasePath
instance is dropped.
Create a BasePath instance based on an existing path on disk.
Note: this function will not ensure that the directory exist nor create the directory. It will also not delete the directory when the instance is dropped.
Create a base path from values describing the project.
Returns the configuration directory inside this base path.
The path looks like $base_path/chains/$chain_id