Struct sc_service::config::NetworkConfiguration [−][src]
pub struct NetworkConfiguration {Show 18 fields
pub net_config_path: Option<PathBuf>,
pub listen_addresses: Vec<Multiaddr, Global>,
pub public_addresses: Vec<Multiaddr, Global>,
pub boot_nodes: Vec<MultiaddrWithPeerId, Global>,
pub node_key: NodeKeyConfig,
pub request_response_protocols: Vec<ProtocolConfig, Global>,
pub default_peers_set: SetConfig,
pub extra_sets: Vec<NonDefaultSetConfig, Global>,
pub client_version: String,
pub node_name: String,
pub transport: TransportConfig,
pub max_parallel_downloads: u32,
pub sync_mode: SyncMode,
pub enable_dht_random_walk: bool,
pub allow_non_globals_in_dht: bool,
pub kademlia_disjoint_query_paths: bool,
pub ipfs_server: bool,
pub yamux_window_size: Option<u32>,
}Expand description
Network service configuration.
Fields
net_config_path: Option<PathBuf>Directory path to store network-specific configuration. None means nothing will be saved.
listen_addresses: Vec<Multiaddr, Global>Multiaddresses to listen for incoming connections.
public_addresses: Vec<Multiaddr, Global>Multiaddresses to advertise. Detected automatically if empty.
boot_nodes: Vec<MultiaddrWithPeerId, Global>List of initial node addresses
node_key: NodeKeyConfigThe node key configuration, which determines the node’s network identity keypair.
request_response_protocols: Vec<ProtocolConfig, Global>List of request-response protocols that the node supports.
default_peers_set: SetConfigConfiguration for the default set of nodes used for block syncing and transactions.
extra_sets: Vec<NonDefaultSetConfig, Global>Configuration for extra sets of nodes.
client_version: StringClient identifier. Sent over the wire for debugging purposes.
node_name: StringName of the node. Sent over the wire for debugging purposes.
transport: TransportConfigConfiguration for the transport layer.
max_parallel_downloads: u32Maximum number of peers to ask the same blocks in parallel.
sync_mode: SyncModeInitial syncing mode.
enable_dht_random_walk: boolTrue if Kademlia random discovery should be enabled.
If true, the node will automatically randomly walk the DHT in order to find new peers.
allow_non_globals_in_dht: boolShould we insert non-global addresses into the DHT?
kademlia_disjoint_query_paths: boolRequire iterative Kademlia DHT queries to use disjoint paths for increased resiliency in the presence of potentially adversarial nodes.
ipfs_server: boolEnable serving block data over IPFS bitswap.
yamux_window_size: Option<u32>Size of Yamux receive window of all substreams. None for the default (256kiB).
Any value less than 256kiB is invalid.
Context
By design, notifications substreams on top of Yamux connections only allow up to N bytes
to be transferred at a time, where N is the Yamux receive window size configurable here.
This means, in practice, that every N bytes must be acknowledged by the receiver before
the sender can send more data. The maximum bandwidth of each notifications substream is
therefore N / round_trip_time.
It is recommended to leave this to None, and use a request-response protocol instead if
a large amount of data must be transferred. The reason why the value is configurable is
that some Substrate users mis-use notification protocols to send large amounts of data.
As such, this option isn’t designed to stay and will likely get removed in the future.
Note that configuring a value here isn’t a modification of the Yamux protocol, but rather a modification of the way the implementation works. Different nodes with different configured values remain compatible with each other.
Implementations
pub fn new<SN, SV>(
node_name: SN,
client_version: SV,
node_key: NodeKeyConfig,
net_config_path: Option<PathBuf>
) -> NetworkConfiguration where
SN: Into<String>,
SV: Into<String>,
pub fn new<SN, SV>(
node_name: SN,
client_version: SV,
node_key: NodeKeyConfig,
net_config_path: Option<PathBuf>
) -> NetworkConfiguration where
SN: Into<String>,
SV: Into<String>,
Create new default configuration
Create new default configuration for localhost-only connection with random port (useful for testing)
Create new default configuration for localhost-only connection with random port (useful for testing)