[−][src]Struct sc_service::TaskManager
Helper struct to manage background/async tasks in Service.
Implementations
impl TaskManager[src]
pub fn spawn_handle(&self) -> SpawnTaskHandle[src]
Get a handle for spawning tasks.
pub fn spawn_essential_handle(&self) -> SpawnEssentialTaskHandle[src]
Get a handle for spawning essential tasks.
pub fn clean_shutdown(self) -> Pin<Box<dyn Future<Output = ()> + Send>>[src]
Send the signal for termination, prevent new tasks to be created, await for all the existing tasks to be finished and drop the object. You can consider this as an async drop.
pub fn future<'a>(
&'a mut self
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'a>>[src]
&'a mut self
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'a>>
Return a future that will end with success if the signal to terminate was sent
(self.terminate()) or with an error if an essential task fails.
Warning
This function will not wait until the end of the remaining task. You must call and await
clean_shutdown() after this.
pub fn terminate(&mut self)[src]
Signal to terminate all the running tasks.