BuildGenesisBlock

Trait BuildGenesisBlock 

pub trait BuildGenesisBlock<Block>
where Block: Block,
{ type BlockImportOperation; // Required method fn build_genesis_block( self, ) -> Result<(Block, Self::BlockImportOperation), Error>; }
Trait for building the genesis block.

Required Associated Types

type BlockImportOperation

The import operation used to import the genesis block into the backend.

Required Methods

fn build_genesis_block( self, ) -> Result<(Block, Self::BlockImportOperation), Error>

Returns the built genesis block along with the block import operation after setting the genesis storage.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Block, B, E> BuildGenesisBlock<Block> for GenesisBlockBuilder<Block, B, E>
where Block: Block, B: Backend<Block>, E: RuntimeVersionOf,